Module debugging

Module debugging 

Debugger attachment detection and wait-for-attach.

Enums

DebuggerState
Debugger attachment state of the current process.

Functions

debugger_state
Determine whether a debugger is attached to the current process.
wait_until_debugger_attached
Block until a debugger attaches, or until the optional timeout elapses.