pub struct DeferredStreamProcessor { /* private fields */ }Expand description
Background processor for streams Handles streams to completion, passing each item from the stream to a callback
Implementations
Sourceimpl DeferredStreamProcessor
impl DeferredStreamProcessor
Sourcepub fn init(&self)
pub fn init(&self)
Initialize the processor before use
Pairs with terminate. Spawns the background task; not idempotent, calling it twice panics dropping the prior un-awaited join handle.
Sourcepub async fn terminate(&self)
pub async fn terminate(&self)
Terminate the processor and ensure all streams are closed
Awaits the background task’s exit. Idempotent: a no-op once already terminated or never initialized.
Sourcepub fn add_stream<T: Send + 'static, S: Stream<Item = T> + Unpin + Send + 'static>(
&self,
receiver: S,
handler: impl FnMut(T) -> PinBoxFutureStatic<DeferredStreamResult> + Send + 'static,
) -> bool
pub fn add_stream<T: Send + 'static, S: Stream<Item = T> + Unpin + Send + 'static>( &self, receiver: S, handler: impl FnMut(T) -> PinBoxFutureStatic<DeferredStreamResult> + Send + 'static, ) -> bool
Queue a stream to process in the background
- ‘receiver’ is the stream to process
- ‘handler’ is the callback to handle each item from the stream
Returns ‘true’ if the stream was added for processing, and ‘false’ if the stream could not be added, possibly due to not being initialized.
Non-blocking; the stream is processed by the background task until exhausted or terminate is called.