pub struct Ifv4Addr {
pub ip: Ipv4Addr,
pub netmask: Ipv4Addr,
pub broadcast: Option<Ipv4Addr>,
}Expand description
Details about the ipv4 address of an interface on this host.
Fields
ip: Ipv4AddrThe IP address of the interface.
netmask: Ipv4AddrThe netmask of the interface.
broadcast: Option<Ipv4Addr>The broadcast address of the interface.
Implementations
Sourceimpl Ifv4Addr
impl Ifv4Addr
Sourcepub fn network(&self) -> Ifv4Addr
pub fn network(&self) -> Ifv4Addr
Convert ip address to the address of the network itself by applying the netmask
Sourcepub fn contains_address(&self, addr: Ipv4Addr) -> bool
pub fn contains_address(&self, addr: Ipv4Addr) -> bool
Whether addr is in this address’s subnet.
Sourcepub fn prefix_len(&self) -> Option<u8>
pub fn prefix_len(&self) -> Option<u8>
CIDR prefix length of the netmask, or None if the netmask is not contiguous.